@@ -1,6 +1,7 @@
 #![cfg_attr(RUSTC_WITH_SPECIALIZATION, feature(min_specialization))]
 #![allow(clippy::integer_arithmetic)]
 pub mod account_info;
+pub mod account_overrides;
 pub mod account_rent_state;
 pub mod accounts;
 pub mod accounts_background_service;
@@ -60,6 +61,7 @@ mod storable_accounts;
 mod system_instruction_processor;
 pub mod transaction_batch;
 pub mod transaction_cost_metrics_sender;
+pub mod transaction_error_metrics;
 pub mod vote_account;
 pub mod vote_parser;
 pub mod vote_sender_types;
